@@ -5,10 +5,17 @@ use squawk_syntax::{SyntaxKind, SyntaxNode, SyntaxToken};
 
 use crate::{Linter, Rule, Violation};
 
+#[derive(Debug)]
+pub enum IgnoreKind {
+    File,
+    Line,
+}
+
 #[derive(Debug)]
 pub struct Ignore {
     pub range: TextRange,
     pub violation_names: HashSet<Rule>,
+    pub kind: IgnoreKind,
 }
 
 fn comment_body(token: &SyntaxToken) -> Option<(&str, TextRange)> {
@@ -34,21 +41,28 @@ fn comment_body(token: &SyntaxToken) -> Option<(&str, TextRange)> {
     None
 }
 
-const IGNORE_TEXT: &str = "squawk-ignore";
+// TODO: maybe in a future version we can rename this to squawk-ignore-line
+const IGNORE_LINE_TEXT: &str = "squawk-ignore";
+const IGNORE_FILE_TEXT: &str = "squawk-ignore-file";
 
-fn ignore_rule_names(token: &SyntaxToken) -> Option<(&str, TextRange)> {
+fn ignore_rule_names(token: &SyntaxToken) -> Option<(&str, TextRange, IgnoreKind)> {
     if let Some((comment_body, range)) = comment_body(token) {
         let without_start = comment_body.trim_start();
         let trim_start_size = comment_body.len() - without_start.len();
         let trimmed_comment = without_start.trim_end();
         let trim_end_size = without_start.len() - trimmed_comment.len();
 
-        if let Some(without_prefix) = trimmed_comment.strip_prefix(IGNORE_TEXT) {
-            let range = TextRange::new(
-                range.start() + TextSize::new((trim_start_size + IGNORE_TEXT.len()) as u32),
-                range.end() - TextSize::new(trim_end_size as u32),
-            );
-            return Some((without_prefix, range));
+        for (prefix, kind) in [
+            (IGNORE_FILE_TEXT, IgnoreKind::File),
+            (IGNORE_LINE_TEXT, IgnoreKind::Line),
+        ] {
+            if let Some(without_prefix) = trimmed_comment.strip_prefix(prefix) {
+                let range = TextRange::new(
+                    range.start() + TextSize::new((trim_start_size + prefix.len()) as u32),
+                    range.end() - TextSize::new(trim_end_size as u32),
+                );
+                return Some((without_prefix, range, kind));
+            }
         }
     }
     None
@@ -60,7 +74,7 @@ pub(crate) fn find_ignores(ctx: &mut Linter, file: &SyntaxNode) {
             rowan::WalkEvent::Enter(NodeOrToken::Token(token))
                 if token.kind() == SyntaxKind::COMMENT =>
             {
-                if let Some((rule_names, range)) = ignore_rule_names(&token) {
+                if let Some((rule_names, range, kind)) = ignore_rule_names(&token) {
                     let mut set = HashSet::new();
                     let mut offset = 0usize;
 
@@ -97,6 +111,7 @@ pub(crate) fn find_ignores(ctx: &mut Linter, file: &SyntaxNode) {
                     ctx.ignore(Ignore {
                         range,
                         violation_names: set,
+                        kind,
                     });
                 }
             }
@@ -108,6 +123,9 @@ pub(crate) fn find_ignores(ctx: &mut Linter, file: &SyntaxNode) {
 #[cfg(test)]
 mod test {
 
+    use insta::assert_debug_snapshot;
+
+    use super::IgnoreKind;
     use crate::{Linter, Rule, find_ignores};
 
     #[test]
@@ -229,4 +247,146 @@ create table test_table (
         let errors = linter.lint(parse, sql);
         assert_eq!(errors.len(), 0);
     }
+
+    #[test]
+    fn file_single_rule() {
+        let sql = r#"
+-- squawk-ignore-file ban-drop-column
+alter table t drop column c cascade;
+        "#;
+        let parse = squawk_syntax::SourceFile::parse(sql);
+
+        let mut linter = Linter::from([]);
+        find_ignores(&mut linter, &parse.syntax_node());
+
+        assert_eq!(linter.ignores.len(), 1);
+        let ignore = &linter.ignores[0];
+        assert!(ignore.violation_names.contains(&Rule::BanDropColumn));
+        assert!(matches!(ignore.kind, IgnoreKind::File));
+    }
+
+    #[test]
+    fn file_ignore_with_all_rules() {
+        let sql = r#"
+-- squawk-ignore-file
+alter table t drop column c cascade;
+        "#;
+        let parse = squawk_syntax::SourceFile::parse(sql);
+
+        let mut linter = Linter::from([]);
+        find_ignores(&mut linter, &parse.syntax_node());
+
+        assert_eq!(linter.ignores.len(), 1);
+        let ignore = &linter.ignores[0];
+        assert!(matches!(ignore.kind, IgnoreKind::File));
+        assert!(ignore.violation_names.is_empty());
+
+        let errors: Vec<_> = linter
+            .lint(parse, sql)
+            .into_iter()
+            .map(|x| x.code)
+            .collect();
+        assert!(errors.is_empty());
+    }
+
+    #[test]
+    fn file_ignore_with_multiple_rules() {
+        let sql = r#"
+-- squawk-ignore-file ban-drop-column, renaming-column
+alter table t drop column c cascade;
+        "#;
+        let parse = squawk_syntax::SourceFile::parse(sql);
+
+        let mut linter = Linter::from([]);
+        find_ignores(&mut linter, &parse.syntax_node());
+
+        assert_eq!(linter.ignores.len(), 1);
+        let ignore = &linter.ignores[0];
+        assert!(ignore.violation_names.contains(&Rule::BanDropColumn));
+        assert!(ignore.violation_names.contains(&Rule::RenamingColumn));
+        assert!(matches!(ignore.kind, IgnoreKind::File));
+    }
+
+    #[test]
+    fn file_ignore_anywhere_works() {
+        let sql = r#"
+alter table t add column x int;
+-- squawk-ignore-file ban-drop-column
+alter table t drop column c cascade;
+        "#;
+        let parse = squawk_syntax::SourceFile::parse(sql);
+
+        let mut linter = Linter::from([]);
+        find_ignores(&mut linter, &parse.syntax_node());
+
+        assert_eq!(linter.ignores.len(), 1);
+        let ignore = &linter.ignores[0];
+        assert!(ignore.violation_names.contains(&Rule::BanDropColumn));
+        assert!(matches!(ignore.kind, IgnoreKind::File));
+    }
+
+    #[test]
+    fn file_ignore_c_style_comment() {
+        let sql = r#"
+/* squawk-ignore-file ban-drop-column */
+alter table t drop column c cascade;
+        "#;
+        let parse = squawk_syntax::SourceFile::parse(sql);
+
+        let mut linter = Linter::from([]);
+        find_ignores(&mut linter, &parse.syntax_node());
+
+        assert_eq!(linter.ignores.len(), 1);
+        let ignore = &linter.ignores[0];
+        assert!(ignore.violation_names.contains(&Rule::BanDropColumn));
+        assert!(matches!(ignore.kind, IgnoreKind::File));
+    }
+
+    #[test]
+    fn file_level_only_ignores_specific_rules() {
+        let mut linter = Linter::with_all_rules();
+        let sql = r#"
+-- squawk-ignore-file ban-drop-column
+alter table t drop column c cascade;
+alter table t2 drop column c2 cascade;
+        "#;
+
+        let parse = squawk_syntax::SourceFile::parse(sql);
+        let errors: Vec<_> = linter
+            .lint(parse, sql)
+            .into_iter()
+            .map(|x| x.code)
+            .collect();
+
+        assert_debug_snapshot!(errors, @r"
+        [
+            PreferRobustStmts,
+            PreferRobustStmts,
+        ]
+        ");
+    }
+
+    #[test]
+    fn file_ignore_at_end_of_file_is_fine() {
+        let mut linter = Linter::with_all_rules();
+        let sql = r#"
+alter table t drop column c cascade;
+alter table t2 drop column c2 cascade;
+-- squawk-ignore-file ban-drop-column
+        "#;
+
+        let parse = squawk_syntax::SourceFile::parse(sql);
+        let errors: Vec<_> = linter
+            .lint(parse, sql)
+            .into_iter()
+            .map(|x| x.code)
+            .collect();
+
+        assert_debug_snapshot!(errors, @r"
+        [
+            PreferRobustStmts,
+            PreferRobustStmts,
+        ]
+        ");
+    }
 }
