@@ -3,7 +3,7 @@ use squawk_syntax::{
     ast::{self, AstNode},
 };
 
-use crate::{Linter, Rule, Violation, text::trim_quotes};
+use crate::{Linter, Rule, Violation, identifier::Identifier};
 
 use super::constraint_missing_not_valid::tables_created_in_transaction;
 
@@ -30,7 +30,7 @@ pub(crate) fn disallow_unique_constraint(ctx: &mut Linter, parse: &Parse<SourceF
                             add_constraint.constraint()
                         {
                             if unique_constraint.using_index().is_none()
-                                && !tables_created.contains(trim_quotes(&table_name))
+                                && !tables_created.contains(&Identifier::new(&table_name))
                             {
                                 ctx.report(Violation::new(
                                     Rule::DisallowedUniqueConstraint,
@@ -65,16 +65,14 @@ pub(crate) fn disallow_unique_constraint(ctx: &mut Linter, parse: &Parse<SourceF
 mod test {
     use insta::assert_debug_snapshot;
 
-    use crate::{Linter, Rule};
+    use crate::{Rule, test_utils::{lint, lint_with_assume_in_transaction}};
 
     #[test]
     fn adding_unique_constraint_err() {
         let sql = r#"
 ALTER TABLE table_name ADD CONSTRAINT field_name_constraint UNIQUE (field_name);
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::DisallowedUniqueConstraint]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::DisallowedUniqueConstraint);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -84,9 +82,7 @@ ALTER TABLE table_name ADD CONSTRAINT field_name_constraint UNIQUE (field_name);
         let sql = r#"
 ALTER TABLE table_name DROP CONSTRAINT field_name_constraint;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::DisallowedUniqueConstraint]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::DisallowedUniqueConstraint);
         assert_eq!(errors.len(), 0);
     }
 
@@ -97,9 +93,7 @@ CREATE UNIQUE INDEX CONCURRENTLY dist_id_temp_idx ON distributors (dist_id);
 ALTER TABLE distributors DROP CONSTRAINT distributors_pkey,
 ADD CONSTRAINT distributors_pkey PRIMARY KEY USING INDEX dist_id_temp_idx;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::DisallowedUniqueConstraint]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::DisallowedUniqueConstraint);
         assert_eq!(errors.len(), 0);
     }
 
@@ -110,9 +104,7 @@ CREATE UNIQUE INDEX CONCURRENTLY "legacy_questiongrouppg_mongo_id_1f8f47d9_uniq_
     ON "legacy_questiongrouppg" ("mongo_id");
 ALTER TABLE "legacy_questiongrouppg" ADD CONSTRAINT "legacy_questiongrouppg_mongo_id_1f8f47d9_uniq" UNIQUE USING INDEX "legacy_questiongrouppg_mongo_id_1f8f47d9_uniq_idx";
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::DisallowedUniqueConstraint]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::DisallowedUniqueConstraint);
         assert_eq!(errors.len(), 0);
     }
 
@@ -127,9 +119,7 @@ CREATE TABLE products (
 ALTER TABLE products ADD CONSTRAINT sku_constraint UNIQUE (sku);
 COMMIT;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::DisallowedUniqueConstraint]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::DisallowedUniqueConstraint);
         assert_eq!(errors.len(), 0);
     }
 
@@ -142,10 +132,7 @@ CREATE TABLE products (
 );
 ALTER TABLE products ADD CONSTRAINT sku_constraint UNIQUE (sku);
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::DisallowedUniqueConstraint]);
-        linter.settings.assume_in_transaction = true;
-        let errors = linter.lint(file, sql);
+        let errors = lint_with_assume_in_transaction(sql, Rule::DisallowedUniqueConstraint);
         assert_eq!(errors.len(), 0);
     }
 
@@ -154,9 +141,7 @@ ALTER TABLE products ADD CONSTRAINT sku_constraint UNIQUE (sku);
         let sql = r#"
 ALTER TABLE foo ADD COLUMN bar text CONSTRAINT foo_bar_unique UNIQUE;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::DisallowedUniqueConstraint]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::DisallowedUniqueConstraint);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -166,9 +151,7 @@ ALTER TABLE foo ADD COLUMN bar text CONSTRAINT foo_bar_unique UNIQUE;
         let sql = r#"
 ALTER TABLE foo ADD COLUMN bar text UNIQUE;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::DisallowedUniqueConstraint]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::DisallowedUniqueConstraint);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
