@@ -3,6 +3,7 @@ use std::collections::HashSet;
 use squawk_syntax::ast::AstNode;
 use squawk_syntax::{Parse, SourceFile, ast};
 
+use crate::identifier::Identifier;
 use crate::{Linter, Rule, Violation};
 
 use crate::visitors::check_not_allowed_types;
@@ -11,8 +12,12 @@ use crate::visitors::is_not_valid_int_type;
 use lazy_static::lazy_static;
 
 lazy_static! {
-    static ref SMALL_INT_TYPES: HashSet<&'static str> =
-        HashSet::from(["smallint", "int2", "smallserial", "serial2",]);
+    static ref SMALL_INT_TYPES: HashSet<Identifier> = HashSet::from([
+        Identifier::new("smallint"),
+        Identifier::new("int2"),
+        Identifier::new("smallserial"),
+        Identifier::new("serial2"),
+    ]);
 }
 
 fn check_ty_for_small_int(ctx: &mut Linter, ty: Option<ast::Type>) {
@@ -37,7 +42,8 @@ pub(crate) fn prefer_bigint_over_smallint(ctx: &mut Linter, parse: &Parse<Source
 mod test {
     use insta::assert_debug_snapshot;
 
-    use crate::{Linter, Rule};
+    use crate::Rule;
+    use crate::test_utils::lint;
 
     #[test]
     fn err() {
@@ -55,9 +61,7 @@ create table users (
     id serial2
 );
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferBigintOverSmallint]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferBigintOverSmallint);
         assert_ne!(errors.len(), 0);
         assert_eq!(errors.len(), 4);
         assert_eq!(
@@ -98,9 +102,7 @@ create table users (
     id serial4
 );
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferBigintOverSmallint]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferBigintOverSmallint);
         assert_eq!(errors.len(), 0);
     }
 }
