@@ -5,7 +5,7 @@ use squawk_syntax::{
     ast::{self, AstNode},
 };
 
-use crate::{Linter, Rule, Violation, text::trim_quotes};
+use crate::{Edit, Fix, Linter, Rule, Violation, identifier::Identifier};
 
 #[derive(PartialEq)]
 enum Constraint {
@@ -16,7 +16,7 @@ enum Constraint {
 pub(crate) fn prefer_robust_stmts(ctx: &mut Linter, parse: &Parse<SourceFile>) {
     let file = parse.tree();
     let mut inside_transaction = ctx.settings.assume_in_transaction;
-    let mut constraint_names: HashMap<String, Constraint> = HashMap::new();
+    let mut constraint_names: HashMap<Identifier, Constraint> = HashMap::new();
 
     let mut total_stmts = 0;
     for _ in file.stmts() {
@@ -46,56 +46,83 @@ pub(crate) fn prefer_robust_stmts(ctx: &mut Linter, parse: &Parse<SourceFile>) {
             }
             ast::Stmt::AlterTable(alter_table) => {
                 for action in alter_table.actions() {
-                    let message_type = match &action {
+                    let (message_type, fix) = match &action {
                         ast::AlterTableAction::DropConstraint(drop_constraint) => {
                             if let Some(constraint_name) = drop_constraint.name_ref() {
                                 constraint_names.insert(
-                                    trim_quotes(constraint_name.text().as_str()).to_string(),
+                                    Identifier::new(constraint_name.text().as_str()),
                                     Constraint::Dropped,
                                 );
                             }
                             if drop_constraint.if_exists().is_some() {
                                 continue;
                             }
-                            ActionErrorMessage::IfExists
+
+                            let fix = if let Some(constraint_token) =
+                                drop_constraint.constraint_token()
+                            {
+                                let at = constraint_token.text_range().end();
+                                let edit = Edit::insert(" if exists", at);
+                                Some(Fix::new("Insert `if exists`", vec![edit]))
+                            } else {
+                                None
+                            };
+
+                            (ActionErrorMessage::IfExists, fix)
                         }
                         ast::AlterTableAction::AddColumn(add_column) => {
                             if add_column.if_not_exists().is_some() {
                                 continue;
                             }
-                            ActionErrorMessage::IfNotExists
+
+                            let fix = if let Some(column_token) = add_column.column_token() {
+                                let at = column_token.text_range().end();
+                                let edit = Edit::insert(" if not exists", at);
+                                Some(Fix::new("Insert `if not exists`", vec![edit]))
+                            } else {
+                                None
+                            };
+                            (ActionErrorMessage::IfNotExists, fix)
                         }
                         ast::AlterTableAction::ValidateConstraint(validate_constraint) => {
                             if let Some(constraint_name) = validate_constraint.name_ref() {
                                 if constraint_names
-                                    .contains_key(trim_quotes(constraint_name.text().as_str()))
+                                    .contains_key(&Identifier::new(constraint_name.text().as_str()))
                                 {
                                     continue;
                                 }
                             }
-                            ActionErrorMessage::None
+                            (ActionErrorMessage::None, None)
                         }
                         ast::AlterTableAction::AddConstraint(add_constraint) => {
                             let constraint = add_constraint.constraint();
                             if let Some(constraint_name) = constraint.and_then(|x| x.name()) {
                                 let name_text = constraint_name.text();
-                                let name = trim_quotes(name_text.as_str());
-                                if let Some(constraint) = constraint_names.get_mut(name) {
+                                let name = Identifier::new(name_text.as_str());
+                                if let Some(constraint) = constraint_names.get_mut(&name) {
                                     if *constraint == Constraint::Dropped {
                                         *constraint = Constraint::Added;
                                         continue;
                                     }
                                 }
                             }
-                            ActionErrorMessage::None
+                            (ActionErrorMessage::None, None)
                         }
                         ast::AlterTableAction::DropColumn(drop_column) => {
                             if drop_column.if_exists().is_some() {
                                 continue;
                             }
-                            ActionErrorMessage::IfExists
+
+                            let fix = if let Some(column_token) = drop_column.column_token() {
+                                let at = column_token.text_range().end();
+                                let edit = Edit::insert(" if exists", at);
+                                Some(Fix::new("Insert `if exists`", vec![edit]))
+                            } else {
+                                None
+                            };
+                            (ActionErrorMessage::IfExists, fix)
                         }
-                        _ => ActionErrorMessage::None,
+                        _ => (ActionErrorMessage::None, None),
                     };
 
                     if inside_transaction {
@@ -114,64 +141,106 @@ pub(crate) fn prefer_robust_stmts(ctx: &mut Linter, parse: &Parse<SourceFile>) {
                         },
                     };
 
-                    ctx.report(Violation::new(
-                        Rule::PreferRobustStmts,
-                        message,
-                        action.syntax().text_range(),
-                        None,
-                    ));
+                    ctx.report(
+                        Violation::new(
+                            Rule::PreferRobustStmts,
+                            message,
+                            action.syntax().text_range(),
+                            None,
+                        )
+                        .with_fix(fix),
+                    );
                 }
             }
             ast::Stmt::CreateIndex(create_index)
                 if create_index.if_not_exists().is_none()
+                    && create_index.name().is_some()
                     && (create_index.concurrently_token().is_some() || !inside_transaction) =>
             {
+                let fix = if let Some(name) = create_index.name() {
+                    let at = name.syntax().text_range().start();
+                    let edit = Edit::insert("if not exists ", at);
+                    Some(Fix::new("Insert `if not exists`", vec![edit]))
+                } else {
+                    None
+                };
                 ctx.report(Violation::new(
                     Rule::PreferRobustStmts,
                     "Missing `IF NOT EXISTS`, the migration can't be rerun if it fails part way through.".into(),
                     create_index.syntax().text_range(),
                     "Use an explicit name for a concurrently created index".to_string(),
-                ));
+                ).with_fix(fix));
             }
             ast::Stmt::CreateTable(create_table)
                 if create_table.if_not_exists().is_none() && !inside_transaction =>
             {
+                let fix = if let Some(table_token) = create_table.table_token() {
+                    let at = table_token.text_range().end();
+                    let edit = Edit::insert(" if not exists", at);
+                    Some(Fix::new("Insert `if not exists`", vec![edit]))
+                } else {
+                    None
+                };
+
                 ctx.report(Violation::new(
                     Rule::PreferRobustStmts,
                     "Missing `IF NOT EXISTS`, the migration can't be rerun if it fails part way through.".into(),
                     create_table.syntax().text_range(),
                     None,
-                ));
+                ).with_fix(fix));
             }
             ast::Stmt::DropIndex(drop_index)
                 if drop_index.if_exists().is_none() && !inside_transaction =>
             {
+                let fix = if let Some(first_index) = drop_index.paths().next() {
+                    let at = first_index.syntax().text_range().start();
+                    let edit = Edit::insert("if exists ", at);
+                    Some(Fix::new("Insert `if exists`", vec![edit]))
+                } else {
+                    None
+                };
+
                 ctx.report(Violation::new(
                     Rule::PreferRobustStmts,
-                    "Missing `IF NOT EXISTS`, the migration can't be rerun if it fails part way through.".into(),
+                    "Missing `IF EXISTS`, the migration can't be rerun if it fails part way through.".into(),
                     drop_index.syntax().text_range(),
                     None,
-                ));
+                ).with_fix(fix));
             }
             ast::Stmt::DropTable(drop_table)
                 if drop_table.if_exists().is_none() && !inside_transaction =>
             {
+                let fix = if let Some(table_token) = drop_table.table_token() {
+                    let at = table_token.text_range().end();
+                    let edit = Edit::insert(" if exists", at);
+                    Some(Fix::new("Insert `if exists`", vec![edit]))
+                } else {
+                    None
+                };
                 ctx.report(Violation::new(
                     Rule::PreferRobustStmts,
-                    "Missing `IF NOT EXISTS`, the migration can't be rerun if it fails part way through.".into(),
+                    "Missing `IF EXISTS`, the migration can't be rerun if it fails part way through.".into(),
                     drop_table.syntax().text_range(),
                     None,
-                ));
+                ).with_fix(fix));
             }
             ast::Stmt::DropType(drop_type)
                 if drop_type.if_exists().is_none() && !inside_transaction =>
             {
+                let fix = if let Some(type_token) = drop_type.type_token() {
+                    let at = type_token.text_range().end();
+                    let edit = Edit::insert(" if exists", at);
+                    Some(Fix::new("Insert `if exists`", vec![edit]))
+                } else {
+                    None
+                };
+
                 ctx.report(Violation::new(
                     Rule::PreferRobustStmts,
-                    "Missing `IF NOT EXISTS`, the migration can't be rerun if it fails part way through.".into(),
+                    "Missing `IF EXISTS`, the migration can't be rerun if it fails part way through.".into(),
                     drop_type.syntax().text_range(),
                     None,
-                ));
+                ).with_fix(fix));
             }
             _ => (),
         }
@@ -180,9 +249,137 @@ pub(crate) fn prefer_robust_stmts(ctx: &mut Linter, parse: &Parse<SourceFile>) {
 
 #[cfg(test)]
 mod test {
-    use insta::assert_debug_snapshot;
+    use insta::{assert_debug_snapshot, assert_snapshot};
 
-    use crate::{Linter, Rule};
+    use crate::{Edit, Linter, Rule, test_utils::{lint, lint_with_assume_in_transaction}};
+
+    fn fix(sql: &str) -> String {
+        let file = squawk_syntax::SourceFile::parse(sql);
+        assert_eq!(file.errors().len(), 0);
+        assert_eq!(file.errors().len(), 0, "Shouldn't start with syntax errors");
+        let mut linter = Linter::from([Rule::PreferRobustStmts]);
+        let errors = linter.lint(file, sql);
+        assert!(!errors.is_empty(), "Should start with linter errors");
+
+        let fixes = errors.into_iter().flat_map(|x| x.fix).collect::<Vec<_>>();
+
+        let mut result = sql.to_string();
+
+        let mut all_edits: Vec<&Edit> = fixes.iter().flat_map(|fix| &fix.edits).collect();
+
+        all_edits.sort_by(|a, b| b.text_range.start().cmp(&a.text_range.start()));
+
+        for edit in all_edits {
+            let start: usize = edit.text_range.start().into();
+            let end: usize = edit.text_range.end().into();
+            let text = edit.text.as_ref().map_or("", |v| v);
+            result.replace_range(start..end, text);
+        }
+
+        let file = squawk_syntax::SourceFile::parse(&result);
+        assert_eq!(
+            file.errors().len(),
+            0,
+            "Shouldn't introduce any syntax errors"
+        );
+        let mut linter = Linter::from([Rule::PreferRobustStmts]);
+        let errors = linter.lint(file, &result);
+        assert_eq!(
+            errors.len(),
+            0,
+            "Fixes should remove all the linter errors."
+        );
+
+        result
+    }
+
+    #[test]
+    fn fix_drop_type_if_exists() {
+        assert_snapshot!(fix("
+drop type t;
+DROP TYPE f;
+"), @r"
+        drop type if exists t;
+        DROP TYPE if exists f;
+        ");
+    }
+
+    #[test]
+    fn fix_drop_index_if_exists() {
+        assert_snapshot!(fix("
+drop index i;
+DROP INDEX CONCURRENTLY idx;
+"), @r"
+        drop index if exists i;
+        DROP INDEX CONCURRENTLY if exists idx;
+        ");
+    }
+
+    #[test]
+    fn fix_drop_table_if_exists() {
+        assert_snapshot!(fix("
+drop table t;
+DROP TABLE users;
+"), @r"
+        drop table if exists t;
+        DROP TABLE if exists users;
+        ");
+    }
+
+    #[test]
+    fn fix_create_index_if_not_exists() {
+        assert_snapshot!(fix("
+create index idx on table (col);
+CREATE INDEX CONCURRENTLY idx2 ON users (email);
+"), @r"
+        create index if not exists idx on table (col);
+        CREATE INDEX CONCURRENTLY if not exists idx2 ON users (email);
+        ");
+    }
+
+    #[test]
+    fn fix_create_table_if_not_exists() {
+        assert_snapshot!(fix("
+create table t (id int);
+CREATE TABLE users (id serial, name text);
+"), @r"
+        create table if not exists t (id int);
+        CREATE TABLE if not exists users (id serial, name text);
+        ");
+    }
+
+    #[test]
+    fn fix_alter_table_add_column_if_not_exists() {
+        assert_snapshot!(fix("
+alter table t add column c text;
+ALTER TABLE users ADD COLUMN email text;
+"), @r"
+        alter table t add column if not exists c text;
+        ALTER TABLE users ADD COLUMN if not exists email text;
+        ");
+    }
+
+    #[test]
+    fn fix_alter_table_drop_column_if_exists() {
+        assert_snapshot!(fix("
+alter table t drop column c;
+ALTER TABLE users DROP COLUMN email;
+"), @r"
+        alter table t drop column if exists c;
+        ALTER TABLE users DROP COLUMN if exists email;
+        ");
+    }
+
+    #[test]
+    fn fix_alter_table_drop_constraint_if_exists() {
+        assert_snapshot!(fix("
+alter table t drop constraint c;
+ALTER TABLE users DROP CONSTRAINT pk_users;
+"), @r"
+        alter table t drop constraint if exists c;
+        ALTER TABLE users DROP CONSTRAINT if exists pk_users;
+        ");
+    }
 
     #[test]
     fn drop_before_end_ok() {
@@ -190,9 +387,7 @@ mod test {
 ALTER TABLE "app_email" DROP CONSTRAINT IF EXISTS "email_uniq";
 ALTER TABLE "app_email" ADD CONSTRAINT "email_uniq" UNIQUE USING INDEX "email_idx";
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -202,9 +397,7 @@ ALTER TABLE "app_email" ADD CONSTRAINT "email_uniq" UNIQUE USING INDEX "email_id
 select 1; -- so we don't skip checking
 DROP INDEX CONCURRENTLY IF EXISTS "email_idx";
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -215,9 +408,7 @@ ALTER TABLE "app_email" DROP CONSTRAINT IF EXISTS "fk_user";
 ALTER TABLE "app_email" ADD CONSTRAINT "fk_user" FOREIGN KEY ("user_id") REFERENCES "app_user" ("id") DEFERRABLE INITIALLY DEFERRED NOT VALID;
 ALTER TABLE "app_email" VALIDATE CONSTRAINT "fk_user";
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -228,9 +419,7 @@ BEGIN;
 ALTER TABLE "core_foo" ADD COLUMN "answer_id" integer NULL;
 COMMIT;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -240,9 +429,7 @@ COMMIT;
 select 1; -- so we don't skip checking
 ALTER TABLE "core_foo" ADD COLUMN IF NOT EXISTS "answer_id" integer NULL;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -252,9 +439,7 @@ ALTER TABLE "core_foo" ADD COLUMN IF NOT EXISTS "answer_id" integer NULL;
 select 1; -- so we don't skip checking
 CREATE INDEX CONCURRENTLY IF NOT EXISTS "core_foo_idx" ON "core_foo" ("answer_id");
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -268,9 +453,7 @@ CREATE TABLE "core_bar" (
 );
 COMMIT;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -282,9 +465,7 @@ CREATE TABLE IF NOT EXISTS "core_bar" (
     "bravo" text NOT NULL
 );
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -298,9 +479,7 @@ DROP TABLE "core_bar";
 DROP TYPE foo;
 COMMIT;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -311,9 +490,7 @@ COMMIT;
 select 1; -- so we don't skip checking
 SELECT 1;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -324,9 +501,7 @@ SELECT 1;
 select 1; -- so we don't skip checking
 INSERT INTO tbl VALUES (a);
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -337,9 +512,7 @@ INSERT INTO tbl VALUES (a);
 select 1; -- so we don't skip checking
 ALTER TABLE "core_foo" DROP CONSTRAINT IF EXISTS "core_foo_idx";
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -349,10 +522,7 @@ ALTER TABLE "core_foo" DROP CONSTRAINT IF EXISTS "core_foo_idx";
 select 1; -- so we don't skip checking
 ALTER TABLE "core_foo" ADD COLUMN "answer_id" integer NULL;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        linter.settings.assume_in_transaction = true;
-        let errors = linter.lint(file, sql);
+        let errors = lint_with_assume_in_transaction(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -363,10 +533,7 @@ DROP INDEX "core_bar_foo_id_idx";
 DROP TABLE "core_bar";
 DROP TYPE foo;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        linter.settings.assume_in_transaction = true;
-        let errors = linter.lint(file, sql);
+        let errors = lint_with_assume_in_transaction(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -378,10 +545,7 @@ CREATE TABLE "core_bar" (
     "bravo" text NOT NULL
 );
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        linter.settings.assume_in_transaction = true;
-        let errors = linter.lint(file, sql);
+        let errors = lint_with_assume_in_transaction(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -392,25 +556,18 @@ CREATE TABLE "core_bar" (
         let sql = r#"
 CREATE INDEX CONCURRENTLY ON "table_name" ("field_name");
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        linter.settings.assume_in_transaction = true;
-        let errors = linter.lint(file, sql);
+        let errors = lint_with_assume_in_transaction(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
     #[test]
-    fn create_index_concurrently_muli_stmts_err() {
+    fn create_index_concurrently_without_name_ok() {
         let sql = r#"
 CREATE INDEX CONCURRENTLY ON "table_name" ("field_name");
 CREATE INDEX CONCURRENTLY ON "table_name" ("field_name");
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        linter.settings.assume_in_transaction = true;
-        let errors = linter.lint(file, sql);
-        assert_ne!(errors.len(), 0);
-        assert_debug_snapshot!(errors);
+        let errors = lint_with_assume_in_transaction(sql, Rule::PreferRobustStmts);
+        assert_eq!(errors.len(), 0);
     }
 
     #[test]
@@ -428,10 +585,7 @@ ALTER TABLE "D" DROP CONSTRAINT "UQ_468cad3743146a81c94b0b114ac";
 
 COMMIT;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        linter.settings.assume_in_transaction = true;
-        let errors = linter.lint(file, sql);
+        let errors = lint_with_assume_in_transaction(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -441,9 +595,7 @@ COMMIT;
 select 1; -- so we don't skip checking
 ALTER TABLE "core_foo" ADD COLUMN "answer_id" integer NULL;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -454,9 +606,7 @@ ALTER TABLE "core_foo" ADD COLUMN "answer_id" integer NULL;
 select 1; -- so we don't skip checking
 CREATE INDEX CONCURRENTLY "core_foo_idx" ON "core_foo" ("answer_id");
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -467,9 +617,7 @@ CREATE INDEX CONCURRENTLY "core_foo_idx" ON "core_foo" ("answer_id");
 select 1; -- so we don't skip checking
 alter table t drop column c cascade;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -480,9 +628,7 @@ alter table t drop column c cascade;
 select 1; -- so we don't skip checking
 alter table t drop column if exists c cascade;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_eq!(errors.len(), 0);
     }
 
@@ -492,9 +638,7 @@ alter table t drop column if exists c cascade;
 select 1; -- so we don't skip checking
 CREATE TABLE "core_bar" ( "id" serial NOT NULL PRIMARY KEY, "bravo" text NOT NULL);
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -505,24 +649,19 @@ CREATE TABLE "core_bar" ( "id" serial NOT NULL PRIMARY KEY, "bravo" text NOT NUL
 select 1; -- so we don't skip checking
 ALTER TABLE "core_foo" DROP CONSTRAINT "core_foo_idx";
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
 
     #[test]
-    fn create_index_concurrently_unnamed_err() {
+    fn create_index_concurrently_unnamed_ok() {
         let sql = r#"
 select 1; -- so we don't skip checking
 CREATE INDEX CONCURRENTLY ON "table_name" ("field_name");
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
-        assert_ne!(errors.len(), 0);
-        assert_debug_snapshot!(errors);
+        let errors = lint(sql, Rule::PreferRobustStmts);
+        assert_eq!(errors.len(), 0);
     }
 
     #[test]
@@ -531,9 +670,7 @@ CREATE INDEX CONCURRENTLY ON "table_name" ("field_name");
 CREATE TABLE IF NOT EXISTS test();
 ALTER TABLE IF EXISTS test ENABLE ROW LEVEL SECURITY;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -544,9 +681,7 @@ ALTER TABLE IF EXISTS test ENABLE ROW LEVEL SECURITY;
 CREATE TABLE IF NOT EXISTS test();
 ALTER TABLE test ENABLE ROW LEVEL SECURITY;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -557,9 +692,7 @@ ALTER TABLE test ENABLE ROW LEVEL SECURITY;
 CREATE TABLE IF NOT EXISTS test();
 ALTER TABLE IF EXISTS test DISABLE ROW LEVEL SECURITY;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -570,11 +703,9 @@ ALTER TABLE IF EXISTS test DISABLE ROW LEVEL SECURITY;
 ALTER TABLE "app_email" DROP CONSTRAINT IF EXISTS "email_uniq";
 ALTER TABLE "app_email" ADD CONSTRAINT "email_uniq" UNIQUE USING INDEX "email_idx";
 -- this second add constraint should error because it's not robust
-ALTER TABLE "app_email" ADD CONSTRAIN "email_uniq" UNIQUE USING INDEX "email_idx";
+ALTER TABLE "app_email" ADD CONSTRAINT "email_uniq" UNIQUE USING INDEX "email_idx";
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -585,9 +716,7 @@ ALTER TABLE "app_email" ADD CONSTRAIN "email_uniq" UNIQUE USING INDEX "email_idx
 select 1; -- so we don't skip checking
 alter table t alter column c set not null;
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
@@ -598,9 +727,7 @@ alter table t alter column c set not null;
 select 1; -- so we don't skip checking
 DROP INDEX CONCURRENTLY "email_idx";
         "#;
-        let file = squawk_syntax::SourceFile::parse(sql);
-        let mut linter = Linter::from([Rule::PreferRobustStmts]);
-        let errors = linter.lint(file, sql);
+        let errors = lint(sql, Rule::PreferRobustStmts);
         assert_ne!(errors.len(), 0);
         assert_debug_snapshot!(errors);
     }
