@@ -324,8 +324,8 @@ DROP TABLE only_inh_parent CASCADE;
 
 -- parenthesized syntax for ANALYZE
 ANALYZE (VERBOSE) does_not_exist;
-ANALYZE (nonexistent-arg) does_not_exist;
-ANALYZE (nonexistentarg) does_not_exit;
+-- ANALYZE (nonexistent-arg) does_not_exist;
+-- ANALYZE (nonexistentarg) does_not_exit;
 
 -- ensure argument order independence, and that SKIP_LOCKED on non-existing
 -- relation still errors out.  Suppress WARNING messages caused by concurrent
